
import * as React from 'react';

import {Text, View, StyleSheet, Image,Pressable,BackHandler} from 'react-native';
import Colors from './themes/Colors';
import images from './themes/Images';


class ErrorBoundary extends React.Component {
  constructor(props) {
    super(props);
    this.state = {hasError: false, error: ''};
  }

  static getDerivedStateFromError(error) {
    // Update state so the next render will show the fallback UI.
    return {hasError: true};
  }

  componentDidCatch(error, errorInfo) {
    // You can also log the error to an error reporting service
    //   logErrorToMyService(error, errorInfo);
    // console.log(error)
    this.setState({error});
  }

  render() {
    if (this.state.hasError) {
      return (
        <View style={styles.container}>
          <Image
            source={images.reward_info_icon}
            resizeMode="contain"
            style={{width: 50, height: 50}}
          />
          <Text style={styles.title}>Something happened!</Text>
          <Text style={styles.text}>{this.state.error?.toString()}</Text>

          <Pressable
            onPress={() =>BackHandler.exitApp() }
            style={styles.button}>
            <Text style={styles.btntxt}>Try Again</Text>
          </Pressable>
        </View>
      );
    }

    return this.props.children;
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    paddingTop: 55,
    backgroundColor: '#ecf0f1',
    padding: 8,
    textAlign: 'center',
  },
  title: {
    fontSize: 24,
    // fontFamily: 'Roboto-Light',
    textAlign: 'center',
    color: Colors.darkBlue,
    paddingVertical: 30,
  },
  icon: {
    fontSize: 48,
  },
  text: {
    marginHorizontal: 10,
    //   marginVertical: 22,
    // fontFamily: 'Roboto-Light',
    color: Colors.PrimaryTextColor,
    lineHeight: 22,
    fontSize: 16,
  },
  btntxt: {
    // fontFamily: 'Roboto-Regular',
    color: Colors.white,
    fontSize: 18,
  },
  button: {
    backgroundColor: Colors.darkBlue,
    width: '80%',
    height: 55,
    borderRadius: 30,
    marginTop: 50,
    alignItems: 'center',
    justifyContent: 'center',
    alignSelf: 'center',
  },
});
export default ErrorBoundary;
