
import React, { useState, useCallback, Fragment } from 'react'
import {ActivityIndicator, View, Text, StyleSheet, Modal, Dimensions, Pressable, GestureResponderEvent, ViewStyle, TextStyle } from 'react-native'


const HEIGHT = Dimensions.get('window').height
const WIDTH = Dimensions.get('window').width

interface propsType {
  title?: string | undefined;
  subTitle?: string | undefined;
  children?: React.ReactNode;
  visible?: boolean | undefined;
  isLoader?: boolean | undefined;
  loaderSize?: "small" | "large";
  loaderColor?: string | undefined;
  horizontal?: boolean | undefined;
  isCustomButton?: boolean | undefined;
  buttonText1?: string | undefined;
  buttonText2?: string | undefined;

  buttonColor1?: string | undefined;
  buttonColor2?: string | undefined;
  buttonTextColor1?: string | undefined;
  buttonTextColor2?: string | undefined;

  titleStyle? : TextStyle | undefined
  subTitleStyle?: TextStyle | undefined

  titleColor?:string | undefined;
  subTitleColor ? :string | undefined;



  style?: ViewStyle | undefined;
  // onPress?:null | undefined
  // onPress(params: any): void
  onPressButton1?: null | ((event: GestureResponderEvent) => void) | undefined;
  onPressButton2?: null | ((event: GestureResponderEvent) => void) | undefined;
  onDismiss?: null | ((event: GestureResponderEvent) => void) | undefined;
}

export default function SweetModal({ children, visible, onPressButton1, onPressButton2, onDismiss, horizontal, title, subTitle, isLoader, loaderSize, loaderColor, isCustomButton,
  buttonText1,
  buttonText2,
  buttonColor1,
  buttonColor2,
  buttonTextColor1,
  buttonTextColor2,
  titleStyle,
  subTitleStyle,
  titleColor,
  subTitleColor

}: propsType) {
  horizontal = horizontal ? horizontal : false
  visible = visible ? visible : false
  loaderColor = loaderColor ? loaderColor : "rose"


    buttonColor1 = buttonColor1 ? buttonColor1 : 'blue',
    buttonColor2 = buttonColor2 ? buttonColor2 : 'red',
    buttonTextColor1 = buttonTextColor1 ? buttonTextColor1 : '#FFF',
    buttonTextColor2 = buttonTextColor2 ? buttonTextColor2 : '#FFF'

    titleColor =titleColor?titleColor:'#333'
    subTitleColor = subTitleColor?subTitleColor:'#333'

  let CONTAINER_HEIGHT = isLoader ? 10 : 20
  let CONTAINER_WIDTH = isLoader ? 80 : 80

  const [numOfLines, setNumOfLines] = useState(0);

  const onTextLayout = useCallback(
    (e: any): void => setNumOfLines(e.nativeEvent.lines.length),
    []
  );

  return (
    <View>
      <Modal
        style={{ flex: 1 }}
        transparent={true}
        visible={visible}>
        <Pressable
          onPress={onDismiss}
          style={{ backgroundColor: 'rgba(0,0,0,0.3)', height: HEIGHT, alignItems: 'center', justifyContent: 'center' }}>

          <View style={{
            borderRadius: 10,
            padding: 20,
            backgroundColor: '#FFF',
            minHeight: (HEIGHT * CONTAINER_HEIGHT / 100),
            alignItems: 'center',
            justifyContent: isLoader ? 'center' : "flex-start",
            width: WIDTH * CONTAINER_WIDTH / 100
          }}>
            {(children && !isCustomButton) ?
              children :
              isLoader ?
                <ActivityIndicator size={loaderSize} color={loaderColor} />
                :
                <Fragment>
                  <Fragment>
                    <Text style={[{ fontSize: 20, lineHeight: 40, marginBottom: 15, textAlign: 'center',color:titleColor },titleStyle]}>
                      {title}
                    </Text>
                    <Text onTextLayout={onTextLayout} style={[{ fontSize: 16, lineHeight: 24, textAlign: numOfLines > 2 ? 'justify' : 'center',color:subTitleColor },subTitleStyle]}>{subTitle}</Text>
                  </Fragment>
                  <View style={{ height: 30 }} />

                  {isCustomButton ? children :
                    <Fragment>
                      {horizontal ?

                        <View style={{ justifyContent: 'space-between', flexDirection: 'column', width: WIDTH * 55 / 100 }}>

                          <Pressable onPress={onPressButton1}
                            style={{ backgroundColor: buttonColor1, height: 40, paddingHorizontal: 10, justifyContent: 'center', borderRadius: 5, minWidth: 70, alignItems: 'center' }}
                          >
                            <Text style={{ color: buttonTextColor1, fontSize: 16 }}>{buttonText1}</Text>
                          </Pressable>

                          <View style={{ height: 10 }} />

                          <Pressable onPress={onPressButton2}
                            style={{ backgroundColor: buttonColor2, height: 40, paddingHorizontal: 10, justifyContent: 'center', borderRadius: 5, minWidth: 70, alignItems: 'center' }}
                          >
                            <Text style={{ color: buttonTextColor2, fontSize: 16 }}>{buttonText2}</Text>
                          </Pressable>

                        </View>
                        :
                        <View style={{ height: 40, justifyContent: 'space-between', flexDirection: 'row', width: WIDTH * 55 / 100 }}>

                          <Pressable onPress={onPressButton1}
                            style={{ backgroundColor: buttonColor1, height: 40, paddingHorizontal: 10, justifyContent: 'center', borderRadius: 5, minWidth: 70, alignItems: 'center' }}
                          >
                            <Text style={{ color: buttonTextColor1, fontSize: 16 }}>{buttonText1}</Text>
                          </Pressable>
                          <Pressable
                            onPress={onPressButton2}
                            style={{ backgroundColor: buttonColor2, height: 40, paddingHorizontal: 10, justifyContent: 'center', borderRadius: 5, minWidth: 70, alignItems: 'center' }}
                          >
                            <Text style={{ color: buttonTextColor2, fontSize: 16 }}>{buttonText2}</Text>
                          </Pressable>
                        </View>
                      }
                    </Fragment>
                  }
                </Fragment>

            }
          </View>
        </Pressable>
      </Modal>
    </View>

  )
}

const styles=StyleSheet.create({
  title:{

  },
  subTitle:{
    
  }
})
