import { StyleSheet, Text, View, Dimensions } from 'react-native';
import React, {
	forwardRef,
	useImperativeHandle,
	useLayoutEffect,
	useRef,
	useState,
} from 'react';
import ToastController, { ToastRef, ToastProps } from './ToastController';



const Toast = () => {

	const WIDTH = Dimensions.get('window').width
	const HEIGHT = Dimensions.get('window').height

	const [toastVisible, setToastVisible] = useState(false);
	const [customMessage, setCustomMessage] = useState("");
	const [otherParam, setOtherParams] = useState<ToastProps>();

	const toastRef = useRef<ToastRef>();

	const toastProps = useRef<ToastProps>();

	useLayoutEffect(() => {
		ToastController.setToastRef(toastRef)
	}, [])

	useImperativeHandle(
		toastRef,
		() => ({
			show: ({ message, title, backgroundColor, type, position, textColor, containerStyle, messageTextStyle, titleTextStyle,duration }: ToastProps) => {
				let positionValue = 30
				duration=duration||1000
				if (type) {
					if (type == "danger")
						backgroundColor = "#bb2124"
					else if (type == "success")
						backgroundColor = "#22bb33"
					else if (type == "default")
						backgroundColor = "#333"
					else if (type == "info")
						backgroundColor = "#5bc0de"
					else if (type == "warning")
						backgroundColor = "#f0ad4e"

				}
				if (position) {
					if (position == "middle") {
						positionValue = HEIGHT * 50 / 100
					}
					else if (position == "bottom") {
						positionValue = HEIGHT * 10 / 100
					}
					else if (position == "top") {
						positionValue = HEIGHT * 90 / 100
					}
				} else {
					positionValue = HEIGHT * 10 / 100
				}

				let otherParams = { message: message, title: title, backgroundColor: backgroundColor, type: type, position: position, positionValue: positionValue, textColor: textColor, containerStyle, messageTextStyle, titleTextStyle,duration }
				setOtherParams(otherParams)
				setToastVisible(true);
				setTimeout(() => {
					setToastVisible(false);
					setCustomMessage("");
				}, duration)
			},
			hide: () => {
				setToastVisible(false);
				setCustomMessage("");
			},
		}),
		[]
	);
	// console.log(22)

	return (
		toastVisible ?
			<View style={[{
				minHeight: 50, width: '90%', backgroundColor: otherParam?.backgroundColor || '#333', position: 'absolute', zIndex: 100,
				bottom: otherParam?.positionValue, alignSelf: 'center', justifyContent: 'center', borderRadius: 5, padding: 10
			}, otherParam?.containerStyle]}>
				{otherParam?.title ? <Text style={[{ color: otherParam?.textColor || '#FFF', fontSize: 18,marginBottom:4,fontWeight:'400' }, otherParam?.titleTextStyle]}>{otherParam?.title}</Text> : null}
				<Text style={[{ color: otherParam?.textColor || '#FFF', fontSize: 16 }, otherParam?.messageTextStyle]}>{otherParam?.message}</Text>
			</View>
			: null

	);
};

export default forwardRef(Toast);

const styles = StyleSheet.create({
	centeredView: {
		flex: 1,
		justifyContent: 'center',
		alignItems: 'center',
		marginTop: 22,
	},
	modalView: {
		margin: 20,
		backgroundColor: 'white',
		borderRadius: 20,
		padding: 35,
		alignItems: 'center',
		shadowColor: '#000',
		shadowOffset: {
			width: 0,
			height: 2,
		},
		shadowOpacity: 0.25,
		shadowRadius: 4,
		elevation: 5,
	},
	button: {
		borderRadius: 20,
		padding: 10,
		elevation: 2,
	},
	buttonOpen: {
		backgroundColor: '#F194FF',
	},
	buttonClose: {
		backgroundColor: '#2196F3',
	},
	textStyle: {
		color: 'white',
		fontWeight: 'bold',
		textAlign: 'center',
	},
	modalText: {
		marginBottom: 15,
		textAlign: 'center',
	},
});