import { Alert, Modal, Pressable, StyleSheet, Text, View, Dimensions } from 'react-native';
import React, {
	forwardRef,
	useImperativeHandle,
	useLayoutEffect,
	useRef,
	useState,
} from 'react';
import ModalController, { CustomModalRef, ModalProps } from './ModalController';

const CustomModal = () => {
	// const{defaultBottonColor}=props
	// const defaultBottonColor="#fff"
	const [modalVisible, setModalVisible] = useState(false);
	const [userRequestProps, setUserRequestProps] = useState<ModalProps>({})

	const modalRef = useRef<CustomModalRef>();


	useLayoutEffect(() => {
		ModalController.setModalRef(modalRef)
	}, [])

	useImperativeHandle(
		modalRef,
		() => ({
			show: ({ message, title, textColor, containerStyle, messageTextStyle, titleTextStyle, cancelable, buttons, onPress, defaultButtonText, defaultButtonStyle, defaultButtonTextStyle }: ModalProps) => {
				let pProps = { message, title, textColor, containerStyle, messageTextStyle, titleTextStyle, cancelable, buttons, onPress, defaultButtonText, defaultButtonStyle, defaultButtonTextStyle }
				setUserRequestProps(pProps)
				setModalVisible(true);
			},
			hide: () => {
				setModalVisible(false);
				setUserRequestProps({})
			},
			onPress(value?: number) {
				userRequestProps.onPress && userRequestProps.onPress(value)
			},
		}),
		[]
	);

	const { message, title, textColor, containerStyle, messageTextStyle, titleTextStyle, cancelable = true, buttons, defaultButtonText = "OK", defaultButtonStyle, defaultButtonTextStyle } = userRequestProps
	return (
		<Modal
			animationType='fade'
			transparent={true}
			visible={modalVisible}
			onRequestClose={() => {
				cancelable &&
					ModalController.hideAlert();
			}}
		>
			<Pressable onPress={() => cancelable && ModalController.hideAlert()} style={styles.centeredView}>
				<View style={[styles.modalView, containerStyle]}>
					{title ? <Text style={[styles.modalTitle, { color: textColor || "#333" }, titleTextStyle]}>{title}</Text> : null}
					{message ? <View style={{ minHeight: 100, justifyContent: title ? 'center' : 'flex-start' }}>
						<Text style={[styles.modalDescText, { color: textColor || "#333" }, messageTextStyle]}>{message}</Text>
					</View>
						: null}
					<View style={styles.buttonContainer}>
						{!buttons ?
							<Pressable
								style={[styles.button, styles.singleButtonClose, defaultButtonStyle]}
								onPress={() => {
									ModalController.hideAlert()
									userRequestProps.onPress && userRequestProps.onPress(0)
								}}
							>
								<Text style={[styles.textStyle, defaultButtonTextStyle]}>{defaultButtonText}</Text>
							</Pressable>
							: null}
						{buttons && buttons.map((element, index) =>
							<Pressable
								key={index}
								style={[styles.button, styles.buttonClose, element.style]}
								onPress={() => {
									ModalController.hideAlert()
									ModalController.onPress(index)
								}}
							>
								<Text style={[styles.textStyle, element.textStyle]}>{element.text}</Text>
							</Pressable>
						)}

					</View>
				</View>
			</Pressable>
		</Modal>
	);
};

export default forwardRef(CustomModal);

const styles = StyleSheet.create({
	centeredView: {
		flex: 1,
		justifyContent: 'center',
		alignItems: 'center',
		marginTop: 22,
		// backgroundColor:'red'
	},
	modalView: {
		margin: 20,
		backgroundColor: 'white',
		borderRadius: 20,
		padding: 35,
		alignItems: 'center',
		shadowColor: '#000',
		maxWidth: '80%',
		minHeight: '20%',
		shadowOffset: {
			width: 0,
			height: 2,
		},
		shadowOpacity: 0.25,
		shadowRadius: 4,
		elevation: 5,
	},
	button: {
		borderRadius: 5,
		// padding: 10,
		elevation: 2,
		height: 40,
		minWidth: 70,
		alignItems: 'center',
		justifyContent: 'center',



	},
	buttonOpen: {
		backgroundColor: 'red',
		// marginRight:'30%',

	},
	buttonClose: {
		backgroundColor: '#2196F3',
		marginLeft: 40

	},
	singleButtonClose: {
		backgroundColor: '#2196F3',
		minWidth: 55


	},
	textStyle: {
		color: 'white',
		fontWeight: '600',
		textAlign: 'center',
		fontSize: 16,

	},
	modalTitle: {
		marginBottom: 15,
		textAlign: 'justify',
		fontSize: 18,
		fontWeight: '600'
	},
	modalDescText: {
		marginBottom: 15,
		textAlign: 'justify',
		// textAlign:'center',
		fontSize: 16,
	},
	buttonContainer: {
		height: 55,
		// backgroundColor:'red',
		// width:'100%',
		flexDirection: 'row',
		justifyContent: 'center',
		alignItems: 'center',
		marginBottom: -15,
		// width:WIDTH*50/100

	}
});